@@ -1,9 +1,11 @@
 package File::ChangeNotify::Watcher;
+BEGIN {
+  $File::ChangeNotify::Watcher::VERSION = '0.14';
+}
 
 use strict;
 use warnings;
-
-our $VERSION = '0.12';
+use namespace::autoclean;
 
 use File::ChangeNotify::Event;
 use List::MoreUtils qw(all);
@@ -108,20 +110,24 @@ sub _remove_directory {
         [ grep { $_ ne $dir } @{ $self->directories() } ] );
 }
 
-no Moose;
-no Moose::Util::TypeConstraints;
-no MooseX::Params::Validate;
-
 __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Base class for all watchers
+
+
+
+=pod
 
 =head1 NAME
 
 File::ChangeNotify::Watcher - Base class for all watchers
 
+=head1 VERSION
+
+version 0.14
+
 =head1 SYNOPSIS
 
     my $watcher =
@@ -236,13 +242,18 @@ and report on them.
 
 =head1 AUTHOR
 
-Dave Rolsky, E<lt>autarch@urth.orgE<gt>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Dave Rolsky, All Rights Reserved.
+This software is Copyright (c) 2010 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
